@@ -27,6 +27,8 @@
 
 #include <gtkmm/liststore.h>
 
+namespace Glom
+{
 
 class Combo_SummaryType : public Gtk::ComboBox
 {
@@ -55,5 +57,7 @@ protected:
   Glib::RefPtr<Gtk::ListStore> m_model;
 };
 
+} //namespace Glom
+
 #endif //GLOM_MODE_DESIGN_COMBO_SUMMARYTYPE_HH
 
