@@ -25,9 +25,20 @@
 #include <glom/libglom/sharedptr.h>
 #include <glom/libglom/data_structure/fieldtypes.h>
 
+#include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
+
+//Avoid including the header here:
+extern "C"
+{
+typedef struct _EpcPublisher EpcPublisher;
+typedef struct _EpcContents EpcContents;
+typedef struct _EpcAuthContext EpcAuthContext;
+}
+
 namespace Gtk
 {
   class Window;
+  class Dialog;
 }
 
 namespace Glom
@@ -82,6 +93,8 @@ protected:
   type_signal_finished m_signal_finished;
 };
 
+class Document_Glom;
+
 /** This is a singleton.
  * Use get_instance().
  */
@@ -95,8 +108,14 @@ protected:
 
 public:
 
+  /** Get the singleton instance.
+   * Use delete_instance() when the program quits.
+   */
   static ConnectionPool* get_instance();
 
+  /// Delete the singleton so it doesn't show up as leaked memory in, for instance, valgrind.
+  static void delete_instance();
+
   bool get_ready_to_connect() const;
   void set_ready_to_connect(bool val = true);
 
@@ -108,26 +127,48 @@ public:
    *
    * @throws an ExceptionConnection when the connection fails.
    */
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   sharedptr<SharedConnection> connect();
+#else
+  sharedptr<SharedConnection> connect(std::auto_ptr<ExceptionConnection>& error);
+#endif
 
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   static sharedptr<SharedConnection> get_and_connect();
+#else
+  static sharedptr<SharedConnection> get_and_connect(std::auto_ptr<ExceptionConnection>& error);
+#endif
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   /** This specifies that Glom should start its own database server instance for this database,
    *  using the database files stored at the specified uri.
    */
   void set_self_hosted(const std::string& data_uri);
+#endif //GLOM_ENABLE_CLIENT_ONLY
 
   /** Creates a new database.
    */
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
   void create_database(const Glib::ustring& database_name);
+#else
+  void create_database(const Glib::ustring& database_name, std::auto_ptr<Glib::Error>& error);
+#endif
 
   void set_host(const Glib::ustring& value);
+
+  /** 0 means any port
+   * Other ports will be tried if the specified port fails.
+   */
+  void set_port(int port);
+  void set_try_other_ports(bool val);
+
   void set_user(const Glib::ustring& value);
   void set_password(const Glib::ustring& value);
   void set_database(const Glib::ustring& value);
 
   Glib::ustring get_host() const;
-  //Glib::ustring get_port() const;
+  int get_port() const;
+  bool get_try_other_ports() const;
   Glib::ustring get_user() const;
   Glib::ustring get_password() const;
   Glib::ustring get_database() const;
@@ -141,21 +182,38 @@ public:
    */
   float get_postgres_server_version();
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   /** Start a database server instance for the exisiting database files.
+   * @param parent_window The parent window (transient for) of any dialogs shown during this operation.
+   * @result Whether the operation was successful.
    */
-  bool start_self_hosting();
+  bool start_self_hosting(Gtk::Window* parent_window);
 
   /** Stop the database server instance for the database files.
+   * @param parent_window The parent window (transient for) of any dialogs shown during this operation.
    */
-  void stop_self_hosting();
+  void stop_self_hosting(Gtk::Window* parent_window);
 
   /** Create new database files, for later use by their own  database server instance.
    * @param parent_window A parent window to use as the transient window when displaying errors.
    */
   bool create_self_hosting(Gtk::Window* parent_window);
 
-  //Show the gda error in a dialog.
-  static bool handle_error(bool cerr_only = false);
+  /** Specify a callback that the ConnectionPool can call to get a pointer to the document.
+   * This callback avoids Connection having to link to App_Glom,
+   * and avoids us worrying about whether a previously-set document (via a set_document() method) is still valid.
+   */ 
+  typedef sigc::slot<Document_Glom*> SlotGetDocument; 
+  void set_get_document_func(const SlotGetDocument& slot);
+
+#ifndef G_OS_WIN32
+  static EpcContents* on_publisher_document_requested (EpcPublisher* publisher, const gchar* key, gpointer user_data);
+  static gboolean on_publisher_document_authentication(EpcAuthContext* context, const gchar* user_name, gpointer user_data);
+
+  static void on_epc_progress_begin(const gchar *title, gpointer user_data);
+  static void on_epc_progress_update(gdouble progress, const gchar* message, gpointer user_data);
+  static void on_epc_progress_end(gpointer user_data);
+#endif // !G_OS_WIN32
 
 
   /** Check whether PostgreSQL is really available for self-hosting,
@@ -169,6 +227,10 @@ public:
    * patch to the implementation.
    */
   static bool install_postgres(Gtk::Window* parent_window);
+#endif // !GLOM_ENABLE_CLIENT_ONLY
+
+  //Show the gda error in a dialog.
+  static bool handle_error(bool cerr_only = false);
 
   /** Check whether the libgda postgres provider is really available, 
    * so we can connect to postgres servers,
@@ -178,20 +240,31 @@ public:
    */
   static bool check_postgres_gda_client_is_available_with_warning();
 
+  /** Postgres can't be started as root. initdb complains.
+   * So just prevent this in general. It is safer anyway.
+   */
+  static bool check_user_is_not_root();
+
 protected:
   void on_sharedconnection_finished();
 
   static bool create_text_file(const std::string& file_uri, const std::string& contents);
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   /** Examine ports one by one, starting at @a starting_port, in increasing order,
    * and return the first one that is available.
    */
   static int discover_first_free_port(int start_port, int end_port);
 
+  Document_Glom* get_document();
+
+#ifndef G_OS_WIN32
   /** Advertize self-hosting via avahi:
    */
   void avahi_start_publishing();
   void avahi_stop_publishing();
+#endif // !G_OS_WIN32
+#endif // !GLOM_ENABLE_CLIENT_ONLY
 
 protected:
 
@@ -204,23 +277,30 @@ protected:
   Glib::RefPtr<Gnome::Gda::Client> m_GdaClient;
   //Gnome::Gda::DataSourceInfo m_GdaDataSourceInfo;
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   bool m_self_hosting_active;
   std::string m_self_hosting_data_uri;
 
+  EpcPublisher* m_epc_publisher;
+  Gtk::Dialog* m_dialog_epc_progress; //For progress while generating certificates.
+#endif // !GLOM_ENABLE_CLIENT_ONLY
+
   Glib::RefPtr<Gnome::Gda::Connection> m_refGdaConnection;
   guint m_sharedconnection_refcount;
   bool m_ready_to_connect;
-  Glib::ustring m_host, m_user, m_password, m_database, m_port;
+  Glib::ustring m_host, m_user, m_password, m_database;
+  int m_port;
+  bool m_try_other_ports;
+
   FieldTypes* m_pFieldTypes;
   float m_postgres_server_version;
 
-public:
-  AvahiPublisher* m_avahi_publisher;
-
 private:
 
   static ConnectionPool* m_instance;
-
+#ifndef GLOM_ENABLE_CLIENT_ONLY
+  SlotGetDocument m_slot_get_document;
+#endif
 };
 
 } //namespace Glom
