@@ -24,7 +24,10 @@
 #include <libglademm.h>
 #include <gtkmm/dialog.h>
 #include <gtkmm/entry.h>
-#include "../fields/combo_textglade.h"
+#include "../../utility_widgets/combo_textglade.h"
+
+namespace Glom
+{
 
 class Dialog_ChooseUser : public Gtk::Dialog
 {
@@ -41,5 +44,7 @@ protected:
   Combo_TextGlade* m_combo_name;
 };
 
+} //namespace Glom
+
 #endif //GLOM_MODE_DESIGN_USERS_DIALOG_NEWGROUP_H
 
