@@ -23,6 +23,7 @@
 #include "dialog_users_list.h"
 #include "dialog_new_group.h"
 #include <glom/libglom/standard_table_prefs_fields.h>
+#include <glom/libglom/glade_utils.h>
 #include <glom/glom_privs.h>
 //#include <libgnome/gnome-i18n.h>
 #include <bakery/App/App_Gtk.h> //For util_bold_message().
@@ -128,7 +129,7 @@ void Dialog_GroupsList::set_document(const Glib::ustring& layout, Document_Glom*
     m_label_table_name->set_text(table_name);
     m_entry_table_title->set_text( document->get_table_title(table_name) );
 
-    Document_Glom::type_mapLayoutGroupSequence mapGroups = document->get_data_layout_groups_plus_new_fields(layout, m_table_name);
+    Document_Glom::type_list_layout_groups mapGroups = document->get_data_layout_groups_plus_new_fields(layout, m_table_name);
 
     //If no information is stored in the document, then start with something:
 
@@ -142,9 +143,8 @@ void Dialog_GroupsList::set_document(const Glib::ustring& layout, Document_Glom*
       for(type_vecLayoutFields::const_iterator iter = table_fields.begin(); iter != table_fields.end(); ++iter)
       {
         LayoutItem_Field item = *iter;
-        item.m_sequence = field_sequence;
 
-        group.add_item(item, field_sequence);
+        group.add_item(item);
 
         ++field_sequence;
       }
@@ -157,9 +157,7 @@ void Dialog_GroupsList::set_document(const Glib::ustring& layout, Document_Glom*
 
     m_model_groups->clear();
 
-    //guint field_sequence = 1; //0 means no sequence
-    //guint group_sequence = 1; //0 means no sequence
-    for(Document_Glom::type_mapLayoutGroupSequence::const_iterator iter = mapGroups.begin(); iter != mapGroups.end(); ++iter)
+    for(Document_Glom::type_list_layout_groups::const_iterator iter = mapGroups.begin(); iter != mapGroups.end(); ++iter)
     {
       sharedptr<const LayoutGroup> group = iter->second;
 
@@ -241,7 +239,7 @@ void Dialog_GroupsList::on_button_group_new()
   Dialog_NewGroup* dialog = 0;
   try
   {
-    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "dialog_new_group");
+    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_new_group");
 
     refXml->get_widget_derived("dialog_new_group", dialog);
   }
@@ -251,7 +249,7 @@ void Dialog_GroupsList::on_button_group_new()
   }
 
   dialog->set_transient_for(*this);
-  int response = dialog->run();
+  int response = Glom::Utils::dialog_run_with_help(dialog, "dialog_new_group");
 
   const Glib::ustring group_name = dialog->m_entry_name->get_text();
 
@@ -262,7 +260,7 @@ void Dialog_GroupsList::on_button_group_new()
 
   if(!group_name.empty())
   {
-    Glib::ustring strQuery = "CREATE GROUP " + group_name;
+    const Glib::ustring strQuery = "CREATE GROUP \"" + group_name + "\"";
     Glib::RefPtr<Gnome::Gda::DataModel> data_model = query_execute(strQuery, this);
 
     //Give the new group some sensible default privileges:
@@ -300,7 +298,7 @@ void Dialog_GroupsList::on_button_group_users()
       Dialog_UsersList* dialog = 0;
       try
       {
-        Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(GLOM_GLADEDIR "glom.glade", "window_users");
+        Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "window_users");
 
         refXml->get_widget_derived("window_users", dialog);
       }
@@ -314,7 +312,7 @@ void Dialog_GroupsList::on_button_group_users()
 
       dialog->set_group(group_name);
 
-      dialog->run();
+      Glom::Utils::dialog_run_with_help(dialog, "window_groups");
 
       remove_view(dialog);
       delete dialog;
@@ -403,10 +401,10 @@ void Dialog_GroupsList::fill_table_list(const Glib::ustring& group_name)
   Document_Glom* pDocument = get_document();
   if(pDocument)
   {
-     // Make sure that these are in the document,
-     // so that the correct groups will be created if we recreate the database from the document:
-     GroupInfo group_info;
-     group_info.set_name(group_name);
+    // Make sure that these are in the document,
+    // so that the correct groups will be created if we recreate the database from the document:
+    GroupInfo group_info;
+    group_info.set_name(group_name);
 
     Document_Glom::type_listTableInfo table_list = pDocument->get_tables(true /* plus system prefs */);
 
@@ -505,7 +503,7 @@ bool Dialog_GroupsList::set_table_privilege(const Glib::ustring& table_name, con
 
 void Dialog_GroupsList::on_treeview_tables_toggled_view(const Glib::ustring& path_string)
 {
-  Gtk::TreePath path(path_string);
+  Gtk::TreeModel::Path path(path_string);
 
   //Get the row from the path:
   Gtk::TreeModel::iterator iter = m_model_tables->get_iter(path);
@@ -544,7 +542,7 @@ void Dialog_GroupsList::on_treeview_tables_toggled_view(const Glib::ustring& pat
 
 void Dialog_GroupsList::on_treeview_tables_toggled_edit(const Glib::ustring& path_string)
 {
-  Gtk::TreePath path(path_string);
+  Gtk::TreeModel::Path path(path_string);
 
   //Get the row from the path:
   Gtk::TreeModel::iterator iter = m_model_tables->get_iter(path);
@@ -568,7 +566,7 @@ void Dialog_GroupsList::on_treeview_tables_toggled_edit(const Glib::ustring& pat
 
 void Dialog_GroupsList::on_treeview_tables_toggled_create(const Glib::ustring& path_string)
 {
-  Gtk::TreePath path(path_string);
+  Gtk::TreeModel::Path path(path_string);
 
   //Get the row from the path:
   Gtk::TreeModel::iterator iter = m_model_tables->get_iter(path);
@@ -592,7 +590,7 @@ void Dialog_GroupsList::on_treeview_tables_toggled_create(const Glib::ustring& p
 
 void Dialog_GroupsList::on_treeview_tables_toggled_delete(const Glib::ustring& path_string)
 {
-  Gtk::TreePath path(path_string);
+  Gtk::TreeModel::Path path(path_string);
 
   //Get the row from the path:
   Gtk::TreeModel::iterator iter = m_model_tables->get_iter(path);
