@@ -21,6 +21,8 @@
 #ifndef GLOM_UTILITY_WIDGETS_TEXTVIEW_GLOM_H
 #define GLOM_UTILITY_WIDGETS_TEXTVIEW_GLOM_H
 
+#include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
+
 #include <gtkmm.h>
 #include <glom/libglom/data_structure/field.h>
 #include "layoutwidgetfield.h"
@@ -63,7 +65,9 @@ protected:
 
   virtual void check_for_change();
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   virtual bool on_button_press_event(GdkEventButton *event); //override
+#endif
 
   virtual App_Glom* get_application();
 
